<!-- markdownlint-disable MD041 -->

<!-- prettier-ignore-start -->
[![Repo][repo-badge]][repo-link]
[![Docs][docs-badge]][docs-link]
[![PyPI license][license-badge]][license-link]
[![PyPI version][pypi-badge]][pypi-link]
[![Conda (channel only)][conda-badge]][conda-link]
[![Code style: ruff][ruff-badge]][ruff-link]
[![uv][uv-badge]][uv-link]

<!--
  For more badges, see
  https://shields.io/category/other
  https://naereen.github.io/badges/
  [pypi-badge]: https://badge.fury.io/py/CNICA
-->

[ruff-badge]: https://img.shields.io/endpoint?url=https://raw.githubusercontent.com/astral-sh/ruff/main/assets/badge/v2.json
[ruff-link]: https://github.com/astral-sh/ruff
[uv-badge]: https://img.shields.io/endpoint?url=https://raw.githubusercontent.com/astral-sh/uv/main/assets/badge/v0.json
[uv-link]: https://github.com/astral-sh/uv
[pypi-badge]: https://img.shields.io/pypi/v/CNICA
[pypi-link]: https://pypi.org/project/CNICA
[docs-badge]: https://img.shields.io/badge/docs-sphinx-informational
[docs-link]: https://pages.nist.gov/CNICA/
[repo-badge]: https://img.shields.io/badge/--181717?logo=github&logoColor=ffffff
[repo-link]: https://github.com/Ivancic91/CNICA
[conda-badge]: https://img.shields.io/conda/v/Ivancic91/CNICA
[conda-link]: https://anaconda.org/Ivancic91/CNICA
[license-badge]: https://img.shields.io/pypi/l/CNICA?color=informational
[license-link]: https://github.com/Ivancic91/CNICA/blob/main/LICENSE

<!-- other links -->

<!-- prettier-ignore-end -->

# `CNICA`

A Python package to perform Coupled Non-negative Independent Component Analysis.

## Overview

This package was designed to solve the problem of D = C^T S, where D is a known
positive matrix, and C and S are unknown positive matrices. This package is 
specifically designed for the  

## Features

Some features...

## Status

This package is actively used by the author. Please feel free to create a pull
request for wanted features and suggestions!

## Quick start

Use one of the following

[comment]: <> ```bash
[comment]: <> pip install CNICA
[comment]: <> ```

[comment]: <> or

[comment]: <> ```bash
[comment]: <> conda install -c Ivancic91 CNICA
[comment]: <> ```

## Example usage

```python
import CNICA
```

<!-- end-docs -->

## Documentation

See the [documentation][docs-link] for further details.

## License

This is free software. See [LICENSE][license-link].

## Related work

Any other stuff to mention....

## Contact

The author can be reached at <ivancic91@gmail.com>.

## Credits

This package was created using
[Cookiecutter](https://github.com/audreyr/cookiecutter) with the
[usnistgov/cookiecutter-nist-python](https://github.com/usnistgov/cookiecutter-nist-python)
template.
